@@ -74,7 +74,7 @@ typedef struct _GnomeVersionInfo GnomeVersionInfo;
 	
 
 GHashTable*        load_applications       (void);
-int                bugzilla_parse_response (SoupMessage *msg,
+char*              bugzilla_parse_response (SoupMessage *msg,
                                             GError **err);
 gboolean	   bugzilla_search_for_package (gpointer key, gpointer value, const char *package);
 
@@ -85,6 +85,7 @@ SoupXmlrpcMessage* bugzilla_create_report  (BugzillaApplication *app,
                                             const char *title,
                                             const char *text,
                                             GtkBuilder *ui,
+					    const char *minidump_file,
                                             GError **err);
 
 #endif /* __BUGZILLA_H__ */
